@@ -1,8 +1,7 @@
 package POEIKC::Daemon;
 
 use strict;
-
-use 5.008_001;#use v5.8.1;
+use v5.8.1;
 
 use warnings;
 use Data::Dumper;
@@ -26,12 +25,8 @@ use POEIKC::Daemon::Utility;
 our @inc = @INC;
 our %inc = %INC;
 our $DEBUG;
-our %opt;
-our %connected;
-
-__PACKAGE__->mk_accessors(qw/pidu argv alias ikc_self_port ikc_self_name server_port server_name/);
-
 
+__PACKAGE__->mk_accessors(qw/pidu argv alias ikc_self_port/);
 
 ####
 
@@ -44,33 +39,12 @@ sub ikc_server_param {
 sub init {
 	my $class = shift || __PACKAGE__ ;
 	my $self = $class->new;
-	%opt = @_;
+	my %opt = @_;
 	$DEBUG = $opt{debug};
 	$self->argv($opt{argv}) if $opt{argv};
 	$self->alias($opt{alias} || 'POEIKCd');
 
-	if ( exists $opt{"0PROGRAM_NAME"} ) {
-		my $pn = $opt{"0PROGRAM_NAME"} || $opt{"name"} || 'poeikcd' ;
-		$0 = sprintf "%s --alias=%s --port=%s",
-				$pn, $self->alias, $opt{port} ;
-	}else{
-		if ($opt{"name"}){
-			$0 = sprintf "poeikcd --name=%s --alias=%s --port=%s",
-				$opt{"name"}, $self->alias, $opt{port} ;
-		}else{
-			$0 = sprintf "poeikcd --alias=%s --port=%s",
-				$self->alias, $opt{port} ;
-		}
-	}
-
-
-	$opt{name} ||= join('_'=>__PACKAGE__ =~ m/(\w+)/g);
-	$self->server_name($opt{name});
-
-	$opt{port} ||= $ARGV[0] || 47225 ;
-	$self->server_port($opt{port});
-
-	$self->ikc_server_param(name		=>$opt{name});
+	$self->ikc_self_port($opt{port} || $ARGV[0] || 47225);
 	$self->ikc_server_param(port		=>$opt{port});
 	$self->ikc_server_param(verbose		=>$opt{Verbose});
 	$self->ikc_server_param(processes	=>$opt{Processes});
@@ -86,7 +60,8 @@ sub init {
 	push @{$opt{Module}}, __PACKAGE__, 'POEIKC::Daemon::Utility';
 	$self->pidu->inc->{load}->{ $_ } = [$INC{Class::Inspector->filename($_)},scalar localtime] for @{$opt{Module}};
 
-	
+	$0 = sprintf "poeikcd --alias=%s --port=%s",
+				$self->alias, $self->ikc_self_port ;#if $0 =~ /poeikcd/;
 	if ($DEBUG) {
 		no warnings 'redefine';
 		*POE::Component::IKC::Responder::DEBUG = sub { 1 };
@@ -114,8 +89,11 @@ sub poe_run {
 sub spawn
 {
 	my $self = shift;
+	my $name = join('_'=>__PACKAGE__ =~ m/(\w+)/g);
 	my %param = (
-		aliases  => [ $self->server_name .'_'. Sys::Hostname::hostname],
+		#port => $self->ikc_self_port ,
+		name => $name,
+		aliases  => [ $name .'_'. Sys::Hostname::hostname],
 		$self->ikc_server_param
 	);
 
@@ -140,7 +118,7 @@ sub _start {
 	my $object = $poe->object;
 
 	printf "%s PID:%s ... Started!! (%s)\n", $0, $$, scalar(localtime);
-
+	
 	my $kernel = $poe->kernel;
 
 	$object->{start_time} = localtime;
@@ -156,7 +134,7 @@ sub _start {
 		IKC =>
 			#publish => $object->alias, Class::Inspector->methods(__PACKAGE__),
 			publish => $object->alias, [qw/
-				_stop
+				_stop 
 				event_respond
 				execute_respond
 				function_respond
@@ -167,84 +145,30 @@ sub _start {
 
 	if ($DEBUG) {
 		$kernel->post(IKC=>'monitor', '*'=>{
-			register	=>'debug_monitor_callback_register',
-			unregister	=>'debug_monitor_callback_unregister',
-			subscribe	=>'debug_monitor_callback_subscribe',
-			unsubscribe	=>'debug_monitor_callback_unsubscribe',
-			shutdown	=>'debug_monitor_callback_shutdown',
-			data		=>'(foo)',
-		});
-	}else{
-		$kernel->post(IKC=>'monitor', '*'=>{
-			register	=>'monitor_register',
-			unregister	=>'monitor_unregister',
+			register=>'callback_register',
+			unregister =>'callback_unregister',
 		});
 	}
 }
 
-
-sub monitor_register
-{
+sub callback_register
+{ 
 	my $poe = sweet_args ;
-	my $object = $poe->object;
-	my $client = (@{$poe->args})[1];
-	$connected{$client}++;
+	my (undef, $client, undef, $data ) = @{$poe->args};
+	POEIKC::Daemon::Utility::_DEBUG_log(register=>$client);
 }
 
-sub monitor_unregister
-{
+sub callback_unregister
+{ 
 	my $poe = sweet_args ;
-	my $object = $poe->object;
-	my $client = (@{$poe->args})[1];
-	delete $connected{$client} if $connected{$client};
+	my (undef, $client, undef, $data ) = @{$poe->args};
+	POEIKC::Daemon::Utility::_DEBUG_log(unregister=>$client);
 }
 
-
-
-
-sub debug_monitor_callback_register
-{
-	my $poe = sweet_args ;
-	my $object = $poe->object;
-	my $client = (@{$poe->args})[1];
-	$connected{$client}++;
-	POEIKC::Daemon::Utility::_DEBUG_log(join " / ", map {$_ ? $_ : ''} @{$poe->args});
-}
-
-sub debug_monitor_callback_unregister
-{
-	my $poe = sweet_args ;
-	my $object = $poe->object;
-	my $client = (@{$poe->args})[1];
-	delete $connected{$client} if $connected{$client};
-	POEIKC::Daemon::Utility::_DEBUG_log(join " / ", map {$_ ? $_ : ''} @{$poe->args});
-}
-
-sub debug_monitor_callback_subscribe
-{
-	my $poe = sweet_args ;
-	POEIKC::Daemon::Utility::_DEBUG_log(join " / ", map {$_ ? $_ : ''} @{$poe->args});
-}
-
-sub debug_monitor_callback_unsubscribe
-{
-	my $poe = sweet_args ;
-	POEIKC::Daemon::Utility::_DEBUG_log(join " / ", map {$_ ? $_ : ''} @{$poe->args});
-}
-
-sub debug_monitor_callback_shutdown
-{
-	my $poe = sweet_args ;
-	POEIKC::Daemon::Utility::_DEBUG_log(join " / ", map {$_ ? $_ : ''} @{$poe->args});
-}
-
-
-
-
 sub sig_stop {
 	my $poe = sweet_args;
 	my $kernel = $poe->kernel;
-	$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log(\%connected);
+	$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log();
 	$kernel->yield('_stop');
 }
 
@@ -253,32 +177,28 @@ sub _stop {
 	my $kernel = $poe->kernel;
 	$kernel->call( IKC => 'shutdown');
 	$kernel->stop();
-	$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log(\%connected);
+	$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log();
 	printf "%s PID:%s ... stopped!! (%s)\n", $0, $$, scalar(localtime);
 }
 
 sub shutdown {
 	my $poe = sweet_args;
 	my $kernel = $poe->kernel;
-	my $object = $poe->object;
-	$object->{shutdown_time} ||= time;
-	$object->{shutdown_cut} ||= 0;
-	if ( $object->{shutdown_cut} < 10 and keys %connected ) {
-		$object->{shutdown_cut}++;
-		$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log($object->{shutdown_time});
-		$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log(\%connected);
-		$kernel->delay(shutdown => 0.05);
-#		$kernel->delay(shutdown => 0.0001);
-		return;
-	}
 	$kernel->call( IKC => 'shutdown');
 	$kernel->stop();
-	$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log($object->{shutdown_time});
-	$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log(\%connected);
-	killall('KILL', $0); # SIGKILL
+	$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log();
+	killall('KILL', $0); # SIGKILL 
 	printf "%s PID:%s ... stopped!! (%s)\n", $0, $$, scalar(localtime);
 }
 
+sub _shutdown {
+	my $poe = sweet_args;
+	$poe->kernel->yield('__shutdown');
+}
+sub __shutdown {
+	my $poe = sweet_args;
+	$poe->kernel->yield('shutdown');
+}
 
 sub something_respond {
 	my $poe = sweet_args;
@@ -291,12 +211,12 @@ sub something_respond {
 	$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log($request);
 
 	my @something = $object->pidu->_distinguish( poe=>$poe, args => $args );
-	@something ?
+	@something ? 
 		$kernel->call($session, execute_respond => @something, $rsvp):
 
 	$kernel->post( IKC => post => $rsvp, {poeikcd_error=>
 		'It is not discriminable. '.
-		q{"ModuleName::functionName" or  "ClassName->methodName" or "AliasName eventName"}
+		q{"ModuleName::functionName" or  "ClassName->methodName" or "AliasName eventName"} 
 	});
 }
 
@@ -331,7 +251,7 @@ sub execute_respond {
 	$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log($from, $args, $rsvp);
 
 	ref $args ne 'ARRAY' and
-		return $kernel->call( IKC => post => $rsvp,
+		return $kernel->call( IKC => post => $rsvp, 
 		{poeikcd_error=>"A parameter is not an Array reference. It is ".ref $args} );
 
 	my $module = shift @{$args};
@@ -351,7 +271,7 @@ sub execute_respond {
 	if ($module eq 'POEIKC::Daemon::Utility'){
 		#$DEBUG and POEIKC::Daemon::Utility::_DEBUG_log($rsvp);
 		my @re = eval {
-			$method ?
+			$method ? 
 			$object->pidu->$method(
 				poe=>$poe, rsvp=>$rsvp, from=>$from, args=>$args
 			) : grep {not /^\_/ and not /^[A-Z]+$/} @{Class::Inspector->methods($module)};
@@ -400,12 +320,12 @@ POEIKC::Daemon - POE IKC daemon
 
 L<poeikcd>
 
-	poeikcd start -p=47225
-	poeikcd stop  -p=47225
+	poeikcd start -p=47225 
+	poeikcd stop  -p=47225 
 	poeikcd --help
 
-And then
-L<poikc> (POK IKC Client)
+And then 
+L<poikc> (POK IKC Client) 
 
 	poikc -H hostname [options] args...
 	poikc --help
@@ -417,7 +337,7 @@ POEIKC::Daemon is daemon of POE::Component::IKC
 
 =head1 AUTHOR
 
-Yuji Suzuki E<lt>yujisuzuki@mail.arbolbell.jpE<gt>
+Yuji Suzuki E<lt>yuji.suzuki.perl@gmail.comE<gt>
 
 =head1 LICENSE
 
